//
// labjackusb.h
//
// MacOSX Version History:
// 
// 0.90 - Initial release
//

#ifndef _LABJACKUSB_H_
#define _LABJACKUSB_H_

#define LJUSB_MACOSX_DRIVER_VERSION 0.90

typedef unsigned long ULONG;
typedef unsigned int UINT;
typedef unsigned char BYTE;
typedef void * HANDLE;
typedef unsigned int DWORD;
//typedef int BOOL; 

//Product IDs	
#define UE9_PRODUCT_ID          9
#define U3_PRODUCT_ID	        3

//UE9 pipes to read/write through
#define UE9_PIPE_EP1_OUT        1
#define UE9_PIPE_EP1_IN         2
#define UE9_PIPE_EP2_OUT        3
#define UE9_PIPE_EP2_IN         4

//U3 pipes to read/write through
#define U3_PIPE_EP1_OUT         1
#define U3_PIPE_EP1_IN          2
#define U3_PIPE_EP2_IN          4


ULONG LJUSB_GetDevCount(ULONG ProductID);
//Returns the total number of LabJack USB devices connected.
//ProductID = The product ID of the devices you want to get the count of.  

HANDLE LJUSB_OpenDevice(UINT DevNum, DWORD dwReserved, ULONG ProductID);
//Obtains a handle for a LabJack USB device.  Currently only one application can have a device 
//open at a time.  Returns NULL if there is an error.  If the device is allready open, NULL is 
//returned and last IO error is set to kIOReturnExclusiveAccess.
//DevNum = The device number of the LabJack USB device you want to open.  For example, if there
//         is one device connected, set DevNum = 1.  If you have two devices connected, then set 
//         DevNum = 1, or DevNum = 2.
//dwReserved = Not used, set to 0.
//ProductID = The product ID of the LabJack USB device.  Currently only the UE9 is supported.

ULONG LJUSB_BulkRead(HANDLE hDevice, ULONG Pipe, BYTE *pBuff, ULONG Count);
//Reads from a bulk endpoint.  Returns the count of the number of bytes read, or 0 on 
//error.  Note: This is a blocking call that returns under the following conditions: 
//The requested amount of data has been received, the device is unplugged from the system, 
//abort pipe is issued on the blocked pipe, or a short packet is received.  
//Pipe = The pipe you want to read your data through (PIPE_EP1_IN or PIPE_EP2_IN).
//*pBuff = Pointer a buffer that will be read from the device.
//Count = The size of the buffer to be read from the device.

ULONG LJUSB_BulkWrite(HANDLE hDevice, ULONG Pipe, BYTE *pBuff, ULONG Count);
//Writes to a bulk endpoint.  Returns the count of the number of bytes wrote, or 0 on 
//error.  Note: This is a blocking call that returns under the following conditions: 
//The requested amount of data has been sent, the device is unplugged from the system or 
//abort pipe is issued on the blocked pipe.
//hDevice = Handle of the LabJack USB device.
//Pipe = The pipe you want to write your data through (PIPE_EP1_OUT or PIPE_EP2_OUT).
//*pBuff = Pointer to the buffer that will be written to the device.
//Count = The size of the buffer to be written to the device.

void LJUSB_CloseDevice(HANDLE hDevice);
//Closes the handle of a LabJack USB device.

int LJUSB_AbortPipe(HANDLE hDevice, ULONG Pipe);
//Aborts pipe transfers of a LabJack USB device.
//hDevice = Handle of the LabJack USB device.
//Pipe = The pipe you want to abort the transfers of.

ULONG LJUSB_GetLastIOError();
//Returns the last IO error that occured with a LabJack.  Refer to the IOKit/IOReturn.h 
//and IOKit/usb/USB.h header files for a list of IO and IOUSB errors.

#endif
